# Enular Library
 
pip install enular

NOTE: Pre-release and development in progress. Expect launch end of 2022.

The Enular Library contains code for backtesting, evaluating and visualising algorithmic trading strategies. It also provides indicators, data sources, and paper trading capabilities. Documentation coming soon. Enular.com

Details:
- Extends Backtrader
- Includes fixes from BackTrader 2
- Data sourced from Yahoo Finance
- Live trading via IB
- Accessibility improvements

In progress:
- Indicator library
- Strategies library
- Bug fixes
- Articles to show how Enular fits in with Backtrader, aims, vision
- Strategy template and how to use indicators, requirements, data, assets A to Z, references to backtrader
- Documentation
- Machine learning capabities
- Articles about ML capabilities
- Forum
- Data feed improvements